.. testsetup:: *

   from pwnlib.rop.srop import *

   from pwnlib import constants
   from pwnlib import shellcraft
   from pwnlib.elf import ELF
   from pwnlib.tubes.process import process

:mod:`pwnlib.rop.srop` --- Sigreturn Oriented Programming
==========================================================

.. automodule:: pwnlib.rop.srop
   :members:
